@@ -47,7 +47,9 @@ class BaseData:
         """Return DataSource Object Name."""
         return self.__class__.__name__
 
-    def find_current_status(self, max_days_old: int, max_periods_old: int):
+    def find_current_status(
+        self, max_days_old: Optional[int], max_periods_old: Optional[int]
+    ):
         """Find current Status for Data.
 
         Current available status:
@@ -70,7 +72,7 @@ class BaseData:
         if self.integration_status == "SUCCESS":
             days_old = (arrow.utcnow() - arrow.get(self.prospect_date)).days
             months_old = days_old / 30
-            expired_by_date = days_old > max_days_old
+            expired_by_date = max_days_old is not None and days_old > max_days_old
             expired_by_period = (
                 max_periods_old is not None and months_old > max_periods_old
             )
