@@ -48,7 +48,7 @@ class BaseSnatch:
 
     serializer_class: Optional[Type[Schema]] = None
     default_timeout: int = 60
-    default_max_days: int = 30
+    default_max_days: Optional[int] = None
     authorization_token_key: Optional[str] = None
     tax_id: Optional[str] = None
     base_url_key: Optional[str] = None
@@ -125,6 +125,7 @@ class BaseSnatch:
         data_obj = self.serializer_class().load(data)
         data_obj.current_environment = self.settings["current_environment"]
         data_obj.datasource_base_url = self.base_url
+        data_obj.tax_id = self.tax_id
         logger.info(f"Data received. Status is: {data_obj.integration_status}")
         return data_obj
 
@@ -147,6 +148,7 @@ class BaseSnatch:
         )
         data_obj.current_environment = self.settings["current_environment"]
         data_obj.datasource_base_url = self.base_url
+        data_obj.tax_id = self.tax_id
         logger.info(f"Data received. Status is: {data_obj.integration_status}")
         return data_obj
 
@@ -159,6 +161,7 @@ class BaseSnatch:
         )
         data_obj.current_environment = self.settings["current_environment"]
         data_obj.datasource_base_url = self.base_url
+        data_obj.tax_id = self.tax_id
         logger.info(f"Data received. Status is: {data_obj.integration_status}")
         return data_obj
 
